@@ -9,5 +9,5 @@ import (
 // Options are the SDK options to use for instantiation for
 // the Nomad plugin.
 var Options = []sdk.Option{
-	sdk.WithComponents(&Platform{}, &Releaser{}),
+	sdk.WithComponents(&Platform{}),
 }
