@@ -321,6 +321,18 @@ func (cs *ConfigSourcer) Documentation() (*docs.Documentation, error) {
 	doc.Description("Read configuration values from Vault.")
 
 	doc.Example(`
+# Setting an input variable dynamically with Vault
+variable "my_api_key" {
+  default = dynamic("vault", {
+    path = "secret/data/keys"
+    key  = "/data/my_api_key"
+  })
+  type        = string
+  sensitive   = true
+  description = "my api key from vault"
+}
+
+# Setting a dynamic variable for an environment variable
 config {
   env = {
     "DATABASE_USERNAME" = dynamic("vault", {
@@ -466,7 +478,7 @@ config {
 		"auth_method",
 		"The authentication method to use for Vault.",
 		docs.Summary(
-			"This can be one of: `aws`, `kubernetes`.\n\n",
+			"This can be one of: `aws`, `approle`, `kubernetes`, `gcp`.\n\n",
 			"When this is set, configuration fields prefixed with the auth method",
 			"type should be set, if required. Configuration fields prefixed with",
 			"non-matching auth method types will be ignored (except for type validation).",
@@ -503,6 +515,22 @@ config {
 		docs.Default("/var/run/secrets/kubernetes.io/serviceaccount/token"),
 	)
 
+	doc.SetField(
+		"approle_role_id",
+		"The role ID of the approle auth method to use for Vault.",
+		docs.Summary(
+			"This is required for the `approle` auth method.",
+		),
+	)
+
+	doc.SetField(
+		"approle_secret_id",
+		"The secret ID of the approle auth method to use for Vault.",
+		docs.Summary(
+			"This is required for the `approle` auth method.",
+		),
+	)
+
 	doc.SetField(
 		"aws_type",
 		"The type of authentication to use for AWS: either `iam` or `ec2`.",
@@ -627,6 +655,9 @@ type sourceConfig struct {
 	AWSRegion           string `hcl:"aws_region,optional"`
 	AWSHeaderValue      string `hcl:"aws_header_value,optional"`
 
+	ApproleRoleId   string `hcl:"approle_role_id,optional"`
+	ApproleSecretId string `hcl:"approle_secret_id,optional"`
+
 	GCPType           string `hcl:"gcp_type,optional"`
 	GCPRole           string `hcl:"gcp_role,optional"`
 	GCPCreds          string `hcl:"gcp_credentials,optional"`
