@@ -100,6 +100,8 @@ func (s *Service) queueJobMulti(
 // does not queue it. This may return multiple jobs if the queue job
 // request requires an on-demand runner. They should all be queued
 // atomically with JobCreate.
+//
+// Precondition: req parameter must be validated
 func (s *Service) queueJobReqToJob(
 	ctx context.Context,
 	req *pb.QueueJobRequest,
@@ -107,20 +109,6 @@ func (s *Service) queueJobReqToJob(
 	log := hclog.FromContext(ctx)
 	job := req.Job
 
-	// Validation
-	if job == nil {
-		return nil, "", status.Errorf(codes.FailedPrecondition, "job must be set")
-	}
-	if job.Operation == nil {
-		// We special case this check and return "Unimplemented" because
-		// the primary case where operation is nil is if a client is sending
-		// us an unsupported operation.
-		return nil, "", status.Errorf(codes.Unimplemented, "operation is nil or unknown")
-	}
-	if err := serverptypes.ValidateJob(job); err != nil {
-		return nil, "", status.Errorf(codes.FailedPrecondition, err.Error())
-	}
-
 	// Verify the project exists and use that to set the default data source
 	log.Debug("checking job project", "project", job.Application.Project)
 	project, err := s.state(ctx).ProjectGet(&pb.Ref_Project{Project: job.Application.Project})
@@ -145,12 +133,41 @@ func (s *Service) queueJobReqToJob(
 		job.DataSource = project.DataSource
 	}
 
+	// If the data source is set to remote, then let the server hook populate it.
+	if job.DataSource.GetRemote() != nil {
+		if s.populateDataSource != nil {
+			job, err = s.populateDataSource(ctx, job)
+			if err != nil {
+				log.Error("error populating data source for job", "error", err)
+				return nil, "", status.Errorf(codes.Internal,
+					"An internal server issue was detected when calculating the data source")
+			}
+
+			// The new job can't still have remote, so if it wasn't updated, then
+			// error out.
+			if job.DataSource.GetRemote() != nil {
+				log.Error("populateDataSource returned another remote DS job")
+				return nil, "", status.Errorf(codes.Internal,
+					"An internal server issue was detected when calculating the data source")
+			}
+		} else {
+			log.Error("job has a remote DataSource but server provided to populateDataSource")
+			// This is a server misconfiguration.
+			if job.DataSource.GetRemote() != nil {
+				return nil, "", status.Errorf(codes.Internal,
+					"An internal server issue was detected when calculating the data source")
+			}
+		}
+	}
+
 	// Get the next id
-	id, err := server.Id()
-	if err != nil {
-		return nil, "", status.Errorf(codes.Internal, "uuid generation failed: %s", err)
+	if job.Id == "" {
+		id, err := server.Id()
+		if err != nil {
+			return nil, "", status.Errorf(codes.Internal, "uuid generation failed: %s", err)
+		}
+		job.Id = id
 	}
-	job.Id = id
 
 	// Validate expiry if we have one
 	job.ExpireTime = nil
@@ -196,6 +213,16 @@ func (s *Service) queueJobReqToJob(
 		if err != nil {
 			return nil, "", err
 		}
+
+		// If we are skipping, then the job we queued is the watch job.
+		if job.OndemandRunnerTask != nil && job.OndemandRunnerTask.SkipOperation {
+			for _, j := range result {
+				if _, ok := j.Operation.(*pb.Job_WatchTask); ok {
+					job = j
+					break
+				}
+			}
+		}
 	}
 
 	return result, job.Id, nil
@@ -205,6 +232,19 @@ func (s *Service) QueueJob(
 	ctx context.Context,
 	req *pb.QueueJobRequest,
 ) (*pb.QueueJobResponse, error) {
+	if req.Job == nil {
+		return nil, status.Errorf(codes.FailedPrecondition, "job must be set")
+	}
+	if req.Job.Operation == nil {
+		// We special case this check and return "Unimplemented" because
+		// the primary case where operation is nil is if a client is sending
+		// us an unsupported operation.
+		return nil, status.Errorf(codes.Unimplemented, "operation is nil or unknown")
+	}
+	if err := serverptypes.ValidateJob(req.Job); err != nil {
+		return nil, status.Errorf(codes.FailedPrecondition, err.Error())
+	}
+
 	jobs, jobId, err := s.queueJobReqToJob(ctx, req)
 	if err != nil {
 		return nil, err
@@ -265,6 +305,20 @@ func (s *Service) wrapJobWithRunner(
 			source.OndemandRunner.Id, source.Id)
 	}
 
+	// Determine if we're skipping this job. This is done for custom tasks.
+	skip := source.OndemandRunnerTask != nil && source.OndemandRunnerTask.SkipOperation
+	if skip {
+		// We only allow noop operations to be skipped out of safety. These
+		// make sense to skip, whereas skipping a build or deploy might be
+		// a bug in the client.
+		_, ok := source.Operation.(*pb.Job_Noop_)
+		if !ok {
+			return nil, status.Errorf(codes.FailedPrecondition,
+				"only noop operations can be skipped with custom tasks, got %T",
+				source.Operation)
+		}
+	}
+
 	// Generate our job to start the ODR
 	startJob, runnerId, err := s.onDemandRunnerStartJob(ctx, source, od)
 	if err != nil {
@@ -287,7 +341,7 @@ func (s *Service) wrapJobWithRunner(
 	}
 
 	// Our source job depends on the starting job.
-	source.DependsOn = []string{startJob.Id}
+	source.DependsOn = append(source.DependsOn, startJob.Id)
 
 	// Job to stop the ODR
 	stopJob, err := s.onDemandRunnerStopJob(ctx, startJob, watchJob, source, od)
@@ -295,20 +349,31 @@ func (s *Service) wrapJobWithRunner(
 		return nil, err
 	}
 
+	// For our task tracking, the primary job is usually the job. But
+	// if we're skipping, then it is the watch task.
+	sourceJob := source
+	if skip {
+		sourceJob = watchJob
+	}
+
 	// Write a Task state with the On-Demand Runner job triple
 	task := &pb.Task{
 		StartJob: &pb.Ref_Job{Id: startJob.Id},
-		TaskJob:  &pb.Ref_Job{Id: source.Id},
+		TaskJob:  &pb.Ref_Job{Id: sourceJob.Id},
 		StopJob:  &pb.Ref_Job{Id: stopJob.Id},
 		WatchJob: &pb.Ref_Job{Id: watchJob.Id},
 		JobState: pb.Task_PENDING,
 	}
+	if skip {
+		// If we're skipping, the primary task job becomes the watch.
+		task.TaskJob = &pb.Ref_Job{Id: watchJob.Id}
+	}
 	if err := s.state(ctx).TaskPut(task); err != nil {
 		return nil, err
 	} else {
 		task, err := s.state(ctx).TaskGet(&pb.Ref_Task{
 			Ref: &pb.Ref_Task_JobId{
-				JobId: source.Id,
+				JobId: sourceJob.Id,
 			},
 		})
 		if err != nil {
@@ -324,20 +389,17 @@ func (s *Service) wrapJobWithRunner(
 		}
 
 		startJob.Task = taskRef
-		source.Task = taskRef
+		sourceJob.Task = taskRef
 		stopJob.Task = taskRef
 		watchJob.Task = taskRef
 	}
 
-	// These must be in order of dependency currently. This is a limitation
-	// of the state.JobCreate API and we should fix it one day. If we get
-	// this wrong it'll just error, so we'll know quickly.
-	return []*pb.Job{
-		startJob,
-		watchJob,
-		source,
-		stopJob,
-	}, nil
+	jobs := []*pb.Job{startJob, watchJob, stopJob}
+	if !skip {
+		jobs = append(jobs, sourceJob)
+	}
+
+	return jobs, nil
 }
 
 // onDemandRunnerStartJob generates a StartJob template for a Task.
@@ -394,7 +456,8 @@ func (s *Service) onDemandRunnerStartJob(
 	// We generate a new login token for each ondemand-runner used. This will inherit
 	// the user of the token to be the user that queued the original job, which is
 	// the correct behavior.
-	token, err := s.newToken(ctx, 60*time.Minute, DefaultKeyId, nil, &pb.Token{
+	token, err := s.newToken(ctx, 60*time.Minute, s.activeAuthKeyId, nil, &pb.Token{
+		// TODO(emp) should this be a Token_Runner_?
 		Kind: &pb.Token_Login_{Login: &pb.Token_Login{
 			UserId: encodedDefaultUserId,
 		}},
@@ -419,15 +482,41 @@ func (s *Service) onDemandRunnerStartJob(
 		envVars[k] = v
 	}
 
-	// Arguments for the runner image. Waypoint is ALWAYS assumed to be
-	// the entrypoint for ODR images.
-	args := []string{"runner", "agent", "-vv", "-id", runnerId, "-odr", "-odr-profile-id", od.Id}
+	// Build our task launch info.
+	launchInfo := &pb.TaskLaunchInfo{}
+	if override := source.OndemandRunnerTask; override != nil {
+		if info := override.LaunchInfo; info != nil {
+			launchInfo = info
+		}
+	}
+	if launchInfo.OciUrl == "" {
+		launchInfo.OciUrl = od.OciUrl
+
+		// Arguments for the runner image. Waypoint is ALWAYS assumed to be
+		// the entrypoint for ODR images if no custom one is specified.
+		launchInfo.Arguments = []string{
+			"runner", "agent", "-vv", "-id", runnerId, "-odr", "-odr-profile-id", od.Id,
+		}
+	}
+
+	// We always default our env vars so that a custom image can still
+	// behave like a runner and has access to the token, runner ID, etc.
+	for k, v := range launchInfo.EnvironmentVariables {
+		envVars[k] = v
+	}
+	launchInfo.EnvironmentVariables = envVars
 
 	job := &pb.Job{
 		// Inherit the workspace/application of the source job.
 		Workspace:   source.Workspace,
 		Application: source.Application,
 
+		// Depend on the same dependencies as the source job. This way,
+		// we don't start up the ODR very early when the job is not ready
+		// to execute.
+		DependsOn:             source.DependsOn,
+		DependsOnAllowFailure: source.DependsOnAllowFailure,
+
 		Operation: &pb.Job_StartTask{
 			StartTask: &pb.Job_StartTaskLaunchOp{
 				Params: &pb.Job_TaskPluginParams{
@@ -435,11 +524,7 @@ func (s *Service) onDemandRunnerStartJob(
 					HclConfig:  od.PluginConfig,
 					HclFormat:  od.ConfigFormat,
 				},
-				Info: &pb.TaskLaunchInfo{
-					OciUrl:               od.OciUrl,
-					EnvironmentVariables: envVars,
-					Arguments:            args,
-				},
+				Info: launchInfo,
 			},
 		},
 	}
@@ -451,16 +536,6 @@ func (s *Service) onDemandRunnerStartJob(
 	}
 	job.Id = id
 
-	// We're going to wait up to 60s for the job be picked up. No reason it won't be
-	// picked up immediately.
-	dur, err := time.ParseDuration("60s")
-	if err != nil {
-		return nil, "", status.Errorf(codes.FailedPrecondition,
-			"Invalid expiry duration: %s", err.Error())
-	}
-
-	job.ExpireTime = timestamppb.New(time.Now().Add(dur))
-
 	// This will be either "Any" or a specific static runner.
 	job.TargetRunner = od.TargetRunner
 
@@ -512,6 +587,13 @@ func (s *Service) onDemandRunnerStopJob(
 	source *pb.Job,
 	od *pb.OnDemandRunnerConfig,
 ) (*pb.Job, error) {
+	depends := []string{startJob.Id, watchJob.Id}
+
+	// Only add the source job if we're not skipping it.
+	if over := source.OndemandRunnerTask; over == nil || !over.SkipOperation {
+		depends = append(depends, source.Id)
+	}
+
 	job := &pb.Job{
 		// Inherit the workspace/application of the source job.
 		Workspace:   source.Workspace,
@@ -519,8 +601,8 @@ func (s *Service) onDemandRunnerStopJob(
 
 		// We depend on both the start job and the main job. We allow them
 		// both to fail, however, because we want to try to stop no matter what.
-		DependsOn:             []string{startJob.Id, watchJob.Id, source.Id},
-		DependsOnAllowFailure: []string{startJob.Id, watchJob.Id, source.Id},
+		DependsOn:             depends,
+		DependsOnAllowFailure: depends,
 
 		// Use the same targeting as the start job. We assume the start job
 		// had proper access to stop, too, so we just copy it.
