@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"strconv"
 	"testing"
 
 	"github.com/stretchr/testify/require"
@@ -40,6 +41,23 @@ func TestPipelineRun(t *testing.T, factory Factory, restartF RestartFactory) {
 		err = s.PipelineRunPut(r)
 		require.NoError(err)
 
+		// We manually add job ids to a PipelineRun over in RunPipeline, so this
+		// replicates how job ids are added to a run messasge
+		for i := 1; i < 4; i++ {
+			is := strconv.Itoa(i)
+			require.NoError(s.JobCreate(serverptypes.TestJobNew(t, &pb.Job{
+				Id: is,
+				Pipeline: &pb.Ref_PipelineStep{
+					PipelineId:  p.Id,
+					RunSequence: r.Sequence,
+				},
+			})))
+
+			r.Jobs = append(r.Jobs, &pb.Ref_Job{Id: string(is)})
+		}
+		err = s.PipelineRunPut(r)
+		require.NoError(err)
+
 		// Get run by pipeline and sequence
 		{
 			resp, err := s.PipelineRunGet(pipeline, 1)
@@ -48,6 +66,10 @@ func TestPipelineRun(t *testing.T, factory Factory, restartF RestartFactory) {
 			require.Equal(r.Id, resp.Id)
 			require.Equal(r.Sequence, resp.Sequence)
 			require.Equal(pipeline.Ref.(*pb.Ref_Pipeline_Id).Id, resp.Pipeline.Ref.(*pb.Ref_Pipeline_Id).Id)
+			require.NotEmpty(resp.Jobs)
+			require.Equal("1", resp.Jobs[0].Id)
+			require.Equal("2", resp.Jobs[1].Id)
+			require.Equal("3", resp.Jobs[2].Id)
 		}
 
 		// Get run by Id
@@ -61,6 +83,7 @@ func TestPipelineRun(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Set another pipeline run
 		r2 := ptypes.TestPipelineRun(t, &pb.PipelineRun{Pipeline: pipeline})
+		r2.Id = "ypr2"
 		err = s.PipelineRunPut(r2)
 		require.NoError(err)
 
@@ -75,6 +98,7 @@ func TestPipelineRun(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Set another pipeline run
 		r3 := ptypes.TestPipelineRun(t, &pb.PipelineRun{Pipeline: pipeline})
+		r3.Id = "pr3"
 		err = s.PipelineRunPut(r3)
 		require.NoError(err)
 
@@ -171,17 +195,17 @@ func TestPipelineRun(t *testing.T, factory Factory, restartF RestartFactory) {
 		pipeline := &pb.Ref_Pipeline{Ref: &pb.Ref_Pipeline_Id{Id: p.Id}}
 
 		// Set Pipeline Run
-		r := ptypes.TestPipelineRun(t, &pb.PipelineRun{Id: "1", Pipeline: pipeline})
+		r := ptypes.TestPipelineRun(t, &pb.PipelineRun{Id: "test1", Pipeline: pipeline})
 		err = s.PipelineRunPut(r)
 		require.NoError(err)
 
 		// Set Another Pipeline Run
-		r2 := ptypes.TestPipelineRun(t, &pb.PipelineRun{Id: "2", Pipeline: pipeline})
+		r2 := ptypes.TestPipelineRun(t, &pb.PipelineRun{Id: "test2", Pipeline: pipeline})
 		err = s.PipelineRunPut(r2)
 		require.NoError(err)
 
 		// Set Another Pipeline Run
-		r3 := ptypes.TestPipelineRun(t, &pb.PipelineRun{Id: "3", Pipeline: pipeline})
+		r3 := ptypes.TestPipelineRun(t, &pb.PipelineRun{Id: "test3", Pipeline: pipeline})
 		err = s.PipelineRunPut(r3)
 		require.NoError(err)
 
