@@ -34,7 +34,9 @@ export function createTerminal(options: TerminalOptions): Terminal {
     terminalOptions.cursorBlink = false;
     terminalOptions.cursorStyle = 'bar';
     terminalOptions.cursorWidth = 1;
-    terminalOptions.theme.cursor = terminalOptions.theme.background;
+    if (terminalOptions.theme) {
+      terminalOptions.theme.cursor = terminalOptions.theme.background;
+    }
   } else {
     terminalOptions.cursorBlink = true;
     terminalOptions.cursorStyle = 'bar';
